'use strict';

const request = require('request-promise-native');

class Base  {
    /**
     * Constructor
     *
     * @constructor
     * @param {string} token API token.
     * @param {string} domain   API domain (default to `api.seo-logs.com`).
     */
    constructor(token, domain) {
        this.token    = token;
        this.domain   = domain;

        if (!domain) {
            this.domain = 'apidev.seo-logs.com';
        }

        this.baseUrl = 'https://' + this.domain + '/api';
    }

    /**
     * Execute api query
     *
     * @example seologs.base.query(options)
     *
     * @param  {Object} options
     * @return {Promise}
     * @see https://github.com/request/request#requestoptions-callback
     */
    query(options = {}) {
        options = Object.assign({
            method: 'GET',
            baseUrl: this.baseUrl,
            uri: '/',
            json: true,
            headers: {
                'Authorization': 'Bearer ' + this.token
            }
        }, options);

        return request(options);
    }
}

module.exports = Base;