'use strict';

const Base = require('./base');

class LogAnalyzer extends Base {
    /**
     * Get log files to import for a Project
     *
     * @method POST
     * @uri /modules/log_analyzer/detect_objects
     * @example seologs.logAnalyzer.detectObjects(projectId);
     *
     * @param {number} projectId the project ID.
     * @param {object} body
     * @returns {Promise}
     */
    detectObjects(projectId, body = {}) {
        const defaultBody = {
            projectId: projectId
        };

        body = {...defaultBody, ...body };

        return this.query({
            form: body,
            method: 'POST',
            uri: '/modules/log_analyzer/detect_objects'
        });
    }

    /**
     * Run job
     *
     * @method POST
     * @uri /modules/log_analyzer/job/run
     * @example seologs.logAnalyzer.runJob(projectId);
     *
     * @param {number} projectId the project ID.
     * @param {object} body
     * @returns {Promise}
     */
    runJob(projectId, body = {}) {
        const defaultBody = {
            projectId: projectId
        };

        body = {...defaultBody, ...body };

        return this.query({
            form: body,
            method: 'POST',
            uri: '/modules/log_analyzer/job/run'
        });
    }

    /**
     * Check if a log format and a log file are compatible
     *
     * @method POST
     * @uri /modules/log_analyzer/validate_log_format
     * @example seologs.logAnalyzer.validateLogFormat(fileId, logFormat);
     *
     * @param {number} fileId the file ID.
     * @param {string} logFormat the log format string.
     * @returns {Promise}
     */
    validateLogFormat(fileId, logFormat) {
        const body = {
            fileId: fileId,
            logFormat: logFormat,
        };

        return this.query({
            form: body,
            method: 'POST',
            uri: '/modules/log_analyzer/validate_log_format'
        });
    }
}

module.exports = LogAnalyzer;