'use strict';

const Base = require('./base');

class LogAnalyzerFileHistory extends Base {
    /**
     * Get file history
     *
     * @method GET
     * @uri /log_analyzer_file_histories/{id}
     * @example seologs.logAnalyzerFileHistory.get(id);
     *
     * @param {number} id the object ID.
     * @returns {Promise}
     */
    get(id) {
        return this.query({
            uri: '/log_analyzer_file_histories/' + id,
        });
    }

    /**
     * Get file history by generationId
     *
     * @method GET
     * @uri /log_analyzer_file_histories/generationId/{id}
     * @example seologs.logAnalyzerFileHistory.getByGenerationId(id);
     *
     * @param {number} id the object generation ID.
     * @returns {Promise}
     */
    getByGenerationId(id) {
        return this.query({
            uri: '/log_analyzer_file_histories/generationId/' + id,
        });
    }

    /**
     * List file histories
     *
     * @method GET
     * @uri /log_analyzer_file_histories
     * @example seologs.logAnalyzerFileHistory.list(qs);
     *
     * @param {object} qs
     * @returns {Promise}
     */
    list(qs = {}) {
        return this.query({
            uri: '/log_analyzer_file_histories',
            qs
        });
    }

    /**
     * Create file history
     *
     * @method POST
     * @uri /log_analyzer_file_histories
     * @example seologs.logAnalyzerFileHistory.create(body);
     *
     * @param {object} body
     * @returns {Promise}
     */
    create(body = {}) {
        return this.query({
            method: 'POST',
            uri: '/log_analyzer_file_histories',
            body
        });
    }

    /**
     * Update file history
     *
     * @method PUT
     * @uri /log_analyzer_file_histories/{id}
     * @example seologs.logAnalyzerFileHistory.update(id, body);
     *
     * @param {number} id the object ID.
     * @param {object} body
     * @returns {Promise}
     */
    update(id, body = {}) {
        return this.query({
            method: 'PUT',
            uri: '/log_analyzer_file_histories/' + id,
            body
        });
    }

    /**
     * Delete file history
     *
     * @method DELETE
     * @uri /log_analyzer_file_histories/{id}
     * @example seologs.logAnalyzerFileHistory.delete(id);
     *
     * @param {number} id the object ID.
     * @returns {Promise}
     */
    delete(id) {
        return this.query({
            method: 'DELETE',
            uri: '/log_analyzer_file_histories/' + id,
        });
    }
}

module.exports = LogAnalyzerFileHistory;