'use strict';

const Base = require('./base');

class Notification extends Base {
    /**
     * Get notification
     *
     * @method GET
     * @uri /notifications/{notificationId}
     * @example seologs.notification.get(notificationId);
     *
     * @param {number} notificationId the notification ID.
     * @returns {Promise}
     */
    get(notificationId) {
        return this.query({
            uri: '/notifications/' + notificationId,
        });
    }

    /**
     * List notifications
     *
     * @method GET
     * @uri /notifications
     * @example seologs.notification.list(qs);
     *
     * @param {object} qs
     * @returns {Promise}
     *
     * ##### qs:
     *
     * - `project`      The project ID.
     * - `user`         Description	The user ID.
     * - `itemsPerPage` The maximum number of the results by query (default `100`).
     */
    list(qs = {}) {
        return this.query({
            uri: '/notifications',
            qs
        });
    }

    /**
     * Create notification
     *
     * @method POST
     * @uri /notifications
     * @example seologs.notification.create(body);
     *
     * @param {object} body
     * @returns {Promise}
     *
     * ##### body:
     *
     * - `level`
     * - `message`
     * - `report_id`
     * - `user_id`
     */
    create(body = {}) {
        return this.query({
            method: 'POST',
            uri: '/notifications',
            body
        });
    }

    /**
     * Delete notification
     *
     * @method DELETE
     * @uri /notifications/{notificationId}
     * @example seologs.notification.delete(notificationId);
     *
     * @param {number} notificationId the notification ID.
     * @returns {Promise}
     */
    delete(notificationId) {
        return this.query({
            method: 'DELETE',
            uri: '/notifications/' + notificationId,
        });
    }
}

module.exports = Notification;