'use strict';

const Base = require('./base');

class ProjectModule extends Base {
    /**
     * Get project module
     *
     * @method GET
     * @uri /projects/{projectId}/modules/{moduleCode}
     * @example seologs.projectModule.get(projectId, moduleCode);
     *
     * @param {number} projectId the project ID.
     * @param {string} moduleCode the module code.
     * @returns {Promise}
     */
    get(projectId, moduleCode) {
        return this.query({
            uri: '/projects/' + projectId + '/modules/' + moduleCode,
        });
    }

    /**
     * Update project module
     *
     * @method PUT
     * @uri /projects/{projectId}/modules/{moduleCode}
     * @example seologs.projectModule.update(projectId, moduleCode, body);
     *
     * @param {number} projectId the project ID.
     * @param {string} moduleCode the module code.
     * @param {object} body
     * @returns {Promise}
     *
     * ##### body:
     *
     * - `enabled`
     * - `options`
     * - `periodStart`
     * - `periodStop`
     * - `status`
     *
     * ##### options:
     *
     * - `host`
     * - `regexFormat`
     * - `path`
     * - `addWww`
     * - `crawlSubdomains`
     * - `maxUrls`
     * - `periodStart`
     * - `periodStop`
     */
    update(id, body = {}) {
        return this.query({
            method: 'PUT',
            uri: '/project_modules/' + id,
            body
        });
    }
}

module.exports = ProjectModule;